#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: dbus
version: 0.10.13
id: dbus-0.10.13-8TjcxfAG8wk5j6htQb95U
key: dbus-0.10.13-8TjcxfAG8wk5j6htQb95U
license: GPL-3
maintainer: Andrey Sverdlichenko <blaze@ruddy.ru>, John Millikin <john@john-millikin.com>
stability: experimental
homepage: https://github.com/rblaze/haskell-dbus#readme
synopsis: A client library for the D-Bus IPC system.
description:
    D-Bus is a simple, message-based protocol for inter-process
    communication, which allows applications to interact with other parts of
    the machine and the user'\''s session using remote procedure calls.
    .
    D-Bus is a essential part of the modern Linux desktop, where it replaces
    earlier protocols such as CORBA and DCOP.
    .
    This library is an implementation of the D-Bus protocol in Haskell. It
    can be used to add D-Bus support to Haskell applications, without the
    awkward interfaces common to foreign bindings.
    .
    Example: connect to the session bus, and get a list of active names.
    .
    @
    &#x7b;-\# LANGUAGE OverloadedStrings \#-&#x7d;
    .
    import Data.List (sort)
    import DBus
    import DBus.Client
    .
    main = do
    &#x20;   client <- connectSession
    &#x20;   //
    &#x20;   \-- Request a list of connected clients from the bus
    &#x20;   reply <- call_ client (methodCall \"\/org\/freedesktop\/DBus\" \"org.freedesktop.DBus\" \"ListNames\")
    &#x20;       &#x7b; methodCallDestination = Just \"org.freedesktop.DBus\"
    &#x20;       &#x7d;
    &#x20;   //
    &#x20;   \-- org.freedesktop.DBus.ListNames() returns a single value, which is
    &#x20;   \-- a list of names (here represented as [String])
    &#x20;   let Just names = fromVariant (methodReturnBody reply !! 0)
    &#x20;   //
    &#x20;   \-- Print each name on a line, sorted so reserved names are below
    &#x20;   \-- temporary names.
    &#x20;   mapM_ putStrLn (sort names)
    @
    .
    >$ ghc --make list-names.hs
    >$ ./list-names
    >:1.0
    >:1.1
    >:1.10
    >:1.106
    >:1.109
    >:1.110
    >ca.desrt.dconf
    >org.freedesktop.DBus
    >org.freedesktop.Notifications
    >org.freedesktop.secrets
    >org.gnome.ScreenSaver
category: Network, Desktop
author: John Millikin <john@john-millikin.com>
exposed: True
indefinite: False
exposed-modules:
    DBus DBus.Client DBus.Internal.Address DBus.Internal.Message
    DBus.Internal.Types DBus.Internal.Wire DBus.Introspection
    DBus.Socket DBus.Transport
abi: 051057594ac0e42197a35926ca56ce7e
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/dbus-0.10.13
library-dirs: /usr/lib/ghc-8.2.1/site-local/dbus-0.10.13
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/dbus-0.10.13
hs-libraries: HSdbus-0.10.13-8TjcxfAG8wk5j6htQb95U
depends:
    base-4.10.0.0 bytestring-0.10.8.2
    cereal-0.5.4.0-AV9aAoAC3OtC6kJvAolohE containers-0.5.10.2
    libxml-sax-0.7.5-33NgxTMLOyhCDrhgX2UeOr
    network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx
    parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh
    random-1.1-DtLcP2Z2iOOC0RwcSmXjBK
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz transformers-0.5.2.0
    unix-2.7.2.2 vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    xml-types-0.3.6-JMA6F2EZctJ1CgZnvNtSRm
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             cereal-0.5.4.0-AV9aAoAC3OtC6kJvAolohE=45711223006f2eb72f62bbe45f216d21
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             libxml-sax-0.7.5-33NgxTMLOyhCDrhgX2UeOr=a0d90da475fbe550a5baa1a942200704
             network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx=dc3f2353580d7555dd3bad96e9f5af9d
             parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh=da03630454c215de5f3965e7b0f0e5da
             random-1.1-DtLcP2Z2iOOC0RwcSmXjBK=e54cb8ee20631772dc74b0ec551441ab
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             unix-2.7.2.2=53184c24da5ad45126d145b2febba63d
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
             xml-types-0.3.6-JMA6F2EZctJ1CgZnvNtSRm=6c7ccd80ac5b0eafd8bef01373d340c6
haddock-interfaces: /usr/share/doc/haskell-dbus/html/dbus.haddock
haddock-html: /usr/share/doc/haskell-dbus/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

